summaryrefslogtreecommitdiff
path: root/tests/unit/misc/test_utilcmds.py
diff options
context:
space:
mode:
Diffstat (limited to 'tests/unit/misc/test_utilcmds.py')
-rw-r--r--tests/unit/misc/test_utilcmds.py23
1 files changed, 5 insertions, 18 deletions
diff --git a/tests/unit/misc/test_utilcmds.py b/tests/unit/misc/test_utilcmds.py
index 79a810efa..96bc8da42 100644
--- a/tests/unit/misc/test_utilcmds.py
+++ b/tests/unit/misc/test_utilcmds.py
@@ -1,19 +1,6 @@
-# Copyright 2016-2021 Florian Bruhin (The Compiler) <mail@qutebrowser.org>
+# SPDX-FileCopyrightText: Florian Bruhin (The Compiler) <mail@qutebrowser.org>
#
-# This file is part of qutebrowser.
-#
-# qutebrowser is free software: you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation, either version 3 of the License, or
-# (at your option) any later version.
-#
-# qutebrowser is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-# GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License
-# along with qutebrowser. If not, see <https://www.gnu.org/licenses/>.
+# SPDX-License-Identifier: GPL-3.0-or-later
"""Tests for qutebrowser.misc.utilcmds."""
@@ -25,17 +12,17 @@ from qutebrowser.api import cmdutils
from qutebrowser.utils import objreg
-def test_repeat_command_initial(mocker, mode_manager):
+def test_cmd_repeat_last_initial(mocker, mode_manager):
"""Test repeat_command first-time behavior.
If :repeat-command is called initially, it should err, because there's
nothing to repeat.
"""
objreg_mock = mocker.patch('qutebrowser.misc.utilcmds.objreg')
objreg_mock.get.return_value = mode_manager
with pytest.raises(cmdutils.CommandError,
match="You didn't do anything yet."):
- utilcmds.repeat_command(win_id=0)
+ utilcmds.cmd_repeat_last(win_id=0)
class FakeWindow:
@@ -25,17 +12,17 @@ from qutebrowser.api import cmdutils
"""Test repeat_command first-time behavior.
- If :repeat-command is called initially, it should err, because there's
+ If :cmd-repeat-last is called initially, it should err, because there's
nothing to repeat.
"""